@@ -22,7 +22,7 @@ class BetterJsonEncoder(json.JSONEncoder):
             return {"val": obj.strftime(DATE_ONLY), "_spec_type": str(date)}
         elif isinstance(obj, Decimal):
             return {"val": str(obj), "_spec_type": str(Decimal)}
-        else:
+        else:  # pragma: no cover
             return super().default(obj)
 
 
@@ -30,7 +30,7 @@ def object_hook(obj):
     if "_spec_type" not in obj:
         return obj
     _spec_type = obj["_spec_type"]
-    if _spec_type not in SERIALIZE_OBJ_MAP:
+    if _spec_type not in SERIALIZE_OBJ_MAP:  # pragma: no cover
         raise TypeError(f'"{obj["val"]}" (type: {_spec_type}) is not JSON serializable')
     return SERIALIZE_OBJ_MAP[_spec_type](obj["val"])
 
